@@ -287,19 +287,19 @@ class TPsimplex:
             file.write('\n\n'+msg+'\n')
             for i in self.variable:
                 file.write(str(i))
-                file.write('\t  ')
+                file.write('\t\t  ')
             file.write('\n')
             p = 0
             for i in self.main_matrix:
                 file.write(self.basic_var[p])
-                file.write('\t')
+                file.write('\t\t')
                 for j in i:
                     if j >= 0:
                         file.write(" "+str(j))
-                        file.write('\t')
+                        file.write('\t\t')
                     elif j < 0:
                         file.write(str(j))
-                        file.write('\t')
+                        file.write('\t\t')
                 p += 1
                 file.write('\n')
 
